netapp_ontap.models.azure_key_vault_state API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.azure_key_vault_state`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AzureKeyVaultStateSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AzureKeyVaultState object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `available: bool GET`

    Set to true when an AKV wrapped internal key is present on all nodes of the cluster.

  `code: str GET`

    Code corresponding to the status message. Returns a 0 if AKV wrapped key is available on all nodes in the cluster.

    Example: 346758

  `message: str GET`

    Error message set when top-level internal key protection key (KEK) availability on cluster is false.

    Example: Top-level internal key protection key (KEK) is unavailable on the following nodes with the associated reasons: Node: node1. Reason: No volumes created yet for the SVM. Wrapped KEK status will be available after creating encrypted volumes.